-- notify popup прикольные уведомления в цветных рамочках, которые потом исчезают
return {
  "rcarriga/nvim-notify",
  config = function()
    local notify = require"notify"
    local stages_util = require"notify.stages.util"
    local opts = {
      ---@usage Animation style one of { "fade", "slide", "fade_in_slide_out", "static" }
      stages = {
        function(state)
          local next_row = stages_util.available_slot(
            state.open_windows,
            state.message.height + 2,
            stages_util.DIRECTION.BOTTOM_UP
          )

          if not next_row then
            return nil
          end

          return {
            relative = "editor",
            anchor = "NE",
            width = state.message.width,
            height = state.message.height,
            col = 1,
            row = next_row,
            border = "rounded",
            style = "minimal",
            opacity = 0
          }
        end,
        function(state, win)
          return {
            opacity = { 100 },
            col = { 1 },
            row = {
              stages_util.slot_after_previous(
                win,
                state.open_windows,
                stages_util.DIRECTION.BOTTOM_UP
              ),
              frequency = 3,
              complete = function()
                return true
              end
            }
          }
        end
      },

      ---@usage Function called when a new window is opened, use for changing win settings/config
      on_open = nil,

      ---@usage Function called when a window is closed
      on_close = nil,

      ---@usage timeout for notifications in ms, default 5000
      timeout = 4000,

      -- Render function for notifications. See notify-render()
      render = "default",

      ---@usage highlight behind the window for stages that change opacity
      background_colour = "#282A36",
      -- background_colour = "Normal",

      ---@usage minimum width for notification windows
      minimum_width = 30,

      ---@usage Icons for the different levels
      icons = {
        ERROR = "",
        WARN = "",
        INFO = "",
        DEBUG = "",
        TRACE = "✎"
      }
    }

    if #vim.api.nvim_list_uis() == 0 then
      -- no need to configure notifications in headless
      return
    end

    notify.setup(opts)
    vim.notify = notify
  end
}

