-- подсветка синтаксиса
return {
  "nvim-treesitter/nvim-treesitter",
  cmd = { "TSInstall", "TSBufEnable", "TSBufDisable", "TSEnable", "TSDisable", "TSModuleInfo" },
  config = function()
    local ts_config = require"nvim-treesitter.configs"

    local default = {
      on_config_done = nil,
      ignore_install = {},
      ensure_installed = {
        "lua",
        "vim",
        "cpp",
        "vue",
        "cmake",
        "css",
        "html",
        "go",
        "glsl",
        "javascript",
        "json",
        "llvm",
        "meson",
        "pug",
        "query",
        "regex",
        "scss",
        "sql",
        "yaml",
        "typescript",
        "dockerfile"
      },
      matchup = {
        enable = false -- mandatory, false will disable the whole extension
        -- disable = { "c", "ruby" },  -- optional, list of language that will be disabled
      },
      highlight = {
        enable = true,
        use_languagetree = true,
        additional_vim_regex_highlighting = true,
        disable = { "latex" }
      },
      context_commentstring = {
        enable = true,
        config = {
          -- Languages that have a single comment style
          typescript = "// %s",
          css = "/* %s */",
          scss = "/* %s */",
          html = "<!-- %s -->",
          svelte = "<!-- %s -->",
          vue = "<!-- %s -->",
          json = ""
        }
      },
      -- indent = {enable = true, disable = {"python", "html", "javascript"}},
      indent = { enable = false, disable = { "yaml" } },
      autotag = { enable = true },
      textobjects = {
        swap = {
          enable = false
          -- swap_next = textobj_swap_keymaps,
        },
        -- move = textobj_move_keymaps,
        select = {
          enable = false
          -- keymaps = textobj_sel_keymaps,
        }
      },
      textsubjects = {
        enable = false,
        keymaps = { ["."] = "textsubjects-smart", [";"] = "textsubjects-big" }
      },
      playground = {
        enable = false,
        disable = {},
        updatetime = 25, -- Debounced time for highlighting nodes in the playground from source code
        persist_queries = false, -- Whether the query persists across vim sessions
        keybindings = {
          toggle_query_editor = "o",
          toggle_hl_groups = "i",
          toggle_injected_languages = "t",
          toggle_anonymous_nodes = "a",
          toggle_language_display = "I",
          focus_language = "f",
          unfocus_language = "F",
          update = "R",
          goto_node = "<cr>",
          show_help = "?"
        }
      },
      rainbow = {
        enable = true,
        extended_mode = true, -- Highlight also non-parentheses delimiters, boolean or table: lang -> boolean
        max_file_lines = 5000 -- Do not enable for files with more than 1000 lines, int
      },
    }
    ts_config.setup(default)
  end
}

